// Copyright 2024 Game Core Tools. All Rights Reserved.

#include "RenameToolBase.h"

#include "ContentBrowserModule.h"
#include "SceneOutlinerDelegates.h"
#include "Engine/Selection.h"

void URenameToolBase::NativeConstruct()
{
	Super::NativeConstruct();
	BindToOnSelectionChanged();
}

void URenameToolBase::NativeDestruct()
{
	UnBindAll();
	Super::NativeDestruct();
}

void URenameToolBase::BindToOnSelectionChanged()
{
	if (FModuleManager::Get().IsModuleLoaded("ContentBrowser"))
	{
		FContentBrowserModule& ContentBrowserModule = FModuleManager::GetModuleChecked<FContentBrowserModule>("ContentBrowser");
		AssetSelectionChangedDelegateHandle = ContentBrowserModule.GetOnAssetSelectionChanged().AddUFunction(this, FName("OnSelectionChanged"));
	}
	
	if (GEditor)
	{
		ActorSelectionDelegateHandle = GEditor->GetSelectedActors()->SelectionChangedEvent.AddUFunction(this, FName("OnSelectionChanged"));
	}
}

void URenameToolBase::UnBindAll() const
{
	if (FModuleManager::Get().IsModuleLoaded("ContentBrowser"))
	{
		FContentBrowserModule& ContentBrowserModule = FModuleManager::GetModuleChecked<FContentBrowserModule>("ContentBrowser");
		ContentBrowserModule.GetOnAssetSelectionChanged().Remove(AssetSelectionChangedDelegateHandle);
	}
	
	if (GEditor)
	{
		GEditor->GetSelectedActors()->SelectionChangedEvent.Remove(ActorSelectionDelegateHandle);
	}
}
